@@ -16,7 +16,7 @@
 # Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 # MA 02110-1301 USA.
 #
-# $Id: CiscoIOS.pm,v 1.1 2006/06/08 20:28:39 evertonm Exp $
+# $Id: CiscoIOS.pm,v 1.2 2006/08/29 19:27:53 evertonm Exp $
 
 package fetchconfig::model::CiscoIOS; # fetchconfig/model/CiscoIOS.pm
 
@@ -148,7 +148,7 @@ sub chat_login {
     }
 
     if ($match !~ /^(\S+)\#$/) {
-	$self->log_error("could not find enable command prompt");
+	$self->log_error("could not match enable command prompt");
 	return undef;
     }
 
@@ -180,7 +180,7 @@ sub expect_enable_prompt {
 }
 
 sub chat_fetch {
-    my ($self, $t, $dev_id, $dev_host, $prompt, $conf_ref) = @_;
+    my ($self, $t, $dev_id, $dev_host, $prompt, $fetch_timeout, $conf_ref) = @_;
     my $ok;
     
     $ok = $t->print('term len 0');
@@ -198,12 +198,22 @@ sub chat_fetch {
 	return 1;
     }
 
+    my $save_timeout;
+    if (defined($fetch_timeout)) {
+        $save_timeout = $t->timeout;
+        $t->timeout($fetch_timeout);
+    }
+
     ($prematch, $match) = $self->expect_enable_prompt($t, $prompt);
     if (!defined($prematch)) {
 	$self->log_error("could not find end of configuration");
 	return 1;
     }
 
+    if (defined($fetch_timeout)) {
+        $t->timeout($save_timeout);
+    }
+
     $self->log_debug("found end of configuration: [$match]");
 
     @$conf_ref = split /\n/, $prematch;
@@ -252,7 +262,9 @@ sub do_fetch {
 
     my @config;
 
-    return if $self->chat_fetch($t, $dev_id, $dev_host, $prompt, \@config);
+    my $fetch_timeout = $self->dev_option($dev_opt_tab, "fetch_timeout");
+
+    return if $self->chat_fetch($t, $dev_id, $dev_host, $prompt, $fetch_timeout, \@config);
 
     $ok = $t->close;
     if (!$ok) {
